<?xml version="1.0"?>
<!--.............................................................-->
<!--.............................................................-->
<!-- Functional Requirements XSL stylesheet                      -->
<!-- To be used ONLY with documents conformant with	         -->
<!-- -//TheFAActory//DTD FunctionalRequirements V1.2//EN	 -->
<!--                                                             -->
<!-- Produces a simple Docbook table with the attributes of each -->
<!-- requirement, as well as a synopsis table.                   -->
<!-- Note that for the synopsis table to work correctly, the     -->
<!-- following images must be provided with the result document: -->
<!-- ./fricons/c[0...9].gif Icons to denote development cycles   -->
<!-- ./fricons/op[y|n].gif  Icons to denote optionality 	 -->
<!-- ./fricons/vi[y|n].gif  Icons to denote visibility		 -->
<!--                                                             -->
<!-- Note: This stylesheet will NOT produce a valid docbook      -->
<!--       document, instead, it will produce an insertable      -->
<!--       section 1 piece that can be used in a container.      -->
<!--                                                             -->
<!-- Author: Fabio Arciniegas A.				 -->
<!-- $Id: req2docbook.xsl,v 1.1.1.1 2001/01/31 19:55:09 Default Exp $ -->
<!--.............................................................-->
<!--.............................................................-->


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

<xsl:template match="/">
	<sect1>
	   <xsl:apply-templates/>
	<!-- TODO: add summary -->
	</sect1>
</xsl:template>

<!--.............................................................-->
<!--                        HEADER RULES                         -->
<!-- Simple rules for heading presentation                       -->
<!--.............................................................-->

<xsl:template match="author">
        <para>
	  <emphasis>Author:</emphasis>
	  <xsl:value-of select="."/>
	</para>
</xsl:template>

<xsl:template match="version">
        <para>
	  <emphasis>Version:</emphasis>
	  <xsl:value-of select="."/>
	</para>
</xsl:template>

<xsl:template match="project">
        <title>Functional Requirements for the <xsl:value-of
        select="."/> project</title>
</xsl:template>


<xsl:template match="fr/header/description">
        <para>
	  <emphasis><xsl:value-of select="."/></emphasis>
	</para>
</xsl:template>

<!--.............................................................-->
<!--              INDIVIDUAL REQUIREMENT RULES                   -->
<!-- Rules for the presentation of each requirement as a table   -->
<!--.............................................................-->
<xsl:template match="req">
    <table pgwide="1" id="{@id}">
	<title><xsl:value-of select="@id"/></title>
        <tgroup cols="3">
	    <colspec colnum="1" colname="c1" align="left"/>
	    <colspec colnum="2" colname="c2" align="left"/>
	    <colspec colnum="3" colname="c3" align="left"/>
	    <tbody>
	       <row>
	         <entry>
		    <para><emphasis>ID:</emphasis><xsl:value-of
		    select="@id"/></para>
		 </entry>
		    <xsl:apply-templates select="./name"/>
	       </row>
	       <row>
		    <xsl:apply-templates select="./optionality"/>
		    <xsl:apply-templates select="./priority"/>
		    <xsl:apply-templates select="./visibility"/>
	       </row>
	       <row>
	            <xsl:apply-templates select="./description"/>
	       </row>
	       <row>
	           <entry><para>
		      <emphasis>Uses:</emphasis>
		      <itemizedlist Mark="bullet">
		      <xsl:if test="not(./uses)">
		           <listitem>
			      <para>None</para>
			   </listitem>
		      </xsl:if>
		      <xsl:for-each select="./uses">
		           <listitem><para><xsl:value-of select="@req"/>(<xref linkend="{@req}"/>)</para>
			   </listitem>
		      </xsl:for-each>
		      </itemizedlist>
		    </para>
		   </entry>

		   <entry namest="c2" nameend="c3" morerows="0">
		    <para>
		      <emphasis>Acceptance Criteria:</emphasis>
		      <xsl:apply-templates select="./acceptance"/>
		    </para>
		   </entry>
	       </row>

	       <row>
	           <entry namest="c1" nameend="c3" morerows="0">
		   <para>
		      <emphasis>Inputs:</emphasis>
		      <itemizedlist Mark="bullet">
		      <xsl:if test="not(./input)">
		           <listitem>
			      <para>None</para>
			   </listitem>
		      </xsl:if>
		      <xsl:for-each select="./input">
		           <listitem>
			      <para><xsl:value-of select="."/></para>
			   </listitem>
		      </xsl:for-each>
		      </itemizedlist>
		   </para>
		   </entry>
	       </row>

	       <row>
	           <entry namest="c1" nameend="c3" morerows="0">
		   <para>
		      <emphasis>Outputs:</emphasis>
		      <itemizedlist Mark="bullet">
		      <xsl:if test="not(./output)">
		           <listitem>
			      <para>None</para>
			   </listitem>
		      </xsl:if>
		      <xsl:for-each select="./output">
		           <listitem>
			      <para><xsl:value-of select="."/></para>
			   </listitem>
		      </xsl:for-each>
		      </itemizedlist>
		    </para>
		   </entry>
	       </row>
	    </tbody>
	</tgroup>
    </table>
</xsl:template>

<xsl:template match="req/name">
  <entry namest="c2" nameend="c3" morerows="0" valign="middle">
        <para>
	      <xsl:value-of select="."/>
	</para>
  </entry>
</xsl:template>

<xsl:template match="req/optionality">
   <entry>
      <para>
        <emphasis>Optionality:</emphasis><xsl:value-of select="@value"/>
      </para>
   </entry>   
</xsl:template>

<xsl:template match="req/visibility">
   <entry>
      <para>
        <emphasis>Visibility:</emphasis><xsl:value-of select="@value"/>
      </para>
   </entry>   
</xsl:template>

<xsl:template match="req/priority">
   <entry>
      <para>
        <emphasis>Priority:</emphasis>developed in cycle <xsl:value-of select="@cycle"/>
      </para>
   </entry>   
</xsl:template>

<xsl:template match="req/description">
   <entry namest="c1" nameend="c3" morerows="0" valign="middle">
      <para>
        <emphasis>Description:</emphasis><xsl:value-of select="."/>
      </para>
   </entry>   
</xsl:template>
</xsl:stylesheet>

