<xsl:stylesheet version="1.0"
	       xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:template match="/fr">
<html>
   <head>
      <title>Requirements for 
         <xsl:value-of select="header/project"/>
      </title>
      <link href="style.css" type="text/css" rel="stylesheet"/>
   </head>
   <body>
     <h1>Requirements for 
         <xsl:value-of select="header/project"/></h1>
    <xsl:value-of select="/fr/header/description"/>
     <h2>Index</h2>
     <xsl:call-template name="index"/>

     <h2>Individual Requirements</h2>
     <xsl:for-each select="requirement">
	<xsl:call-template name="req"/>
        <br/>
     </xsl:for-each>
   </body>
</html>
</xsl:template>

<!-- Index Generation -->
<xsl:template name="index">
   <table>
   <xsl:for-each select="/fr/requirement">	
      <tr>
        <td>
          <xsl:number format="I."/>
        </td>
        <td>
          <a href="{concat('#',@id)}">
          <xsl:value-of select="name"/>
          </a>
        </td>
      </tr>
   </xsl:for-each>
   </table>
</xsl:template>


<!-- this template is called for each requirement -->	
<xsl:template name="req">
 <a name="{concat('#',@id)}"/> <!-- so the index links work -->
 <table border="1" width="100%">
  <tr>
    <td width="15%" valign="top" align="left">
     <!--The same font effect can be achieved by other 
         means, but for the sake of simplicity in the explanation, 
	 this method takes precedence -->
        <font face="Arial Black" size="1">ID</font>
        <xsl:value-of select="@id"/>
    </td>
    <td width="2%" valign="top" align="left">
        <font face="Arial Black" size="1">Priority</font>
        <!-- Insert as number copies of dot.gif that equals the 
             priority of the requirement --> 
        <xsl:call-template name="insert-dot">
	  <xsl:with-param name="number" select="@priority"/>
        </xsl:call-template>
    </td>
    <td width="83%" colspan="2" bgcolor="#FFFF99" 
        valign="top" align="left">
        <font face="Arial Black" size="3">
	  <xsl:value-of select="name"/>
        </font>
    </td>
  </tr>
  <tr>
    <td width="66%" colspan="3" rowspan="2" valign="top" align="left">
        <font face="Arial Black" size="1">Description<br/></font>
        <font face="MS Sans Serif">
           <xsl:copy-of select="description/*"/>
        </font>
    </td>
    <td width="34%" valign="top" align="left">
        <font face="Arial Black" size="1">Inputs</font>
      <ul>
        <xsl:for-each select="input/entry">
          <li><font face="MS Sans Serif">
                <xsl:value-of select="."/>
              </font>
          </li>
        </xsl:for-each>
      </ul>
    </td>
  </tr>
  <tr>
    <td width="34%" valign="top" align="left">
      <font face="Arial Black" size="1">Outputs</font>
      <ul>
        <xsl:for-each select="output/result">
          <li><font face="MS Sans Serif">
                <xsl:value-of select="."/>
              </font>
          </li>
        </xsl:for-each>
      </ul>
    </td>
  </tr>
  <tr>
    <td width="66%" colspan="3" valign="top" align="left">
       <font face="Arial Black" size="1">Anomaly Description<br/>
      </font>
      <font face="MS Sans Serif">
         <xsl:copy-of select="anomaly/description/*"/>
      </font>
      <font face="Arial Black" size="1"><br/> 
      Required behavior</font>
     <font face="MS Sans Serif">
         <xsl:copy-of select="anomaly/behavior/*"/>        
     </font>
    </td>
    <td width="34%" valign="top" align="left" rowspan="2">
     <font face="Arial Black" size="1">Acceptance
      Criteria</font>
     <font face="MS Sans Serif">
         <xsl:copy-of select="acceptance/*"/>        
     </font>
    </td>
  </tr>
 </table>
</xsl:template>

<!-- Recursive function to insert dots -->
<xsl:template name="insert-dot">
  <xsl:param name="number" select="5"/>
  <xsl:if test="$number &gt; 0">
    <img src="dot.gif"/>
     <xsl:call-template name="insert-dot">
	<xsl:with-param name="number" select="$number - 1"/>
     </xsl:call-template>
  </xsl:if>
</xsl:template>

</xsl:stylesheet>









