//----------------------------------------------------------------------------
//~Author: Fabio Arciniegas A.
//~Name: TransformServlet
//~Description:       Transform the results of the DBParser into a page,
//                     according with the device  
//
//----------------------------------------------------------------------------
//             This code has been formated to fit in 80 columns
//----------------------------------------------------------------------------
package com.faa.xslt.tutorial;

// Classes
import javax.servlet.http.    HttpServlet;
import javax.servlet.http.    HttpServletRequest;
import javax.servlet.http.    HttpServletResponse;
import javax.servlet.         ServletOutputStream;
import javax.servlet.         RequestDispatcher;
import java.io.               File; 

import com.faa.xslt.tutorial. XSLTCoordinator;

// Interfaces
import javax.servlet. ServletException;

// Exceptions
import java.io. IOException;

  /** 
      Transform the results of the DBParser into a page, according with the device
   */
public class TransformServlet extends HttpServlet
{
  /** 
     Simply call the transformation method in the XSLTCoordinator. that simple!
     This class should only be called from the contents side box
      @param req the request
      @param res the response
   */
 
    public void doPost(HttpServletRequest req, HttpServletResponse res)
	throws ServletException, IOException
	       
    {

	out = res.getOutputStream();
	String type = req.getParameter("type"); // the type of transformation
	if(type.compareTo("xhtml") == 0)
	    res.setContentType("text/html");
	if(type.compareTo("svg") == 0)
	    res.setContentType("image/svg-xml");
	if(type.compareTo("text") == 0)
	    res.setContentType("text/plain");
	if(type.compareTo("wml") == 0)
	    res.setContentType("text/vnd.wap.wml");
	
	transform(type);
	
	 RequestDispatcher rd = getServletContext().getRequestDispatcher(
                                "/app/results/"+type+".xml");
	 try
	 {
	     rd.forward(req,res);
	 }
	 catch(Exception e)
	 {
	     out.println("Unable to show the results!. Check logs.");
	     System.out.println(e);
	 }

    }

    public void doGet(HttpServletRequest req, HttpServletResponse res)
	throws ServletException, IOException
	       
	{
	    doPost(req,res);
	}

  /** 

     call the transformation method in the XSLTCoordinator and store the result
      @param type the type of transformation (the name of the stylesheet)
   */
 
    private synchronized void transform(String type)
    {
	String outputFile = outputPrefix + type + ".xml";
	String stylesheet = stylesheetPrefix + type + ".xsl";
	
	try 
	{
	    XSLTCoordinator c = new XSLTCoordinator(new File(outputFile),properties);
	    c.transform(stylesheet);
	}
       catch (java.lang.Exception e) 
        {
	    try {
		out.println("Error transforming the data.Check logs");
	    }
	    catch(IOException ie)
	    {
		ie.printStackTrace(System.err);
	    }
	    e.printStackTrace(System.err);
	}

    }

    private static final String outputPrefix     = "bugtracker\\app\\results\\";
    private static final String stylesheetPrefix = "bugtracker\\stylesheets\\";
    private static final String properties = "bugtracker.properties";
    private ServletOutputStream out;
}












