//----------------------------------------------------------------------------
//~Author: Fabio Arciniegas A.
//~Name: XSLTCoordinator
//~Description: A class to mediate the interaction of JRun and an XSLT 
//              processor. Basically a faade for calling XT.
//
// For educational purposes only. No warranties.
//----------------------------------------------------------------------------
//             This code has been formated to fit in 80 columns
//----------------------------------------------------------------------------
package com.faa.xslt.tutorial;
 
// Classes
import java.sql.   Connection;
import java.sql.   DriverManager;
import java.sql.   Statement;
import java.sql.   ResultSet;
import java.util.  Properties;
import java.util.  Vector;
import java.io.    FileInputStream;
import java.io.    FileOutputStream;
import java.io.    OutputStream;
import java.io.    IOException;
import java.io.    File;
import java.io.    FileDescriptor;
import java.net.   URL;

import org.xml.sax.*;
import com.jclark.xsl.sax. XSLProcessorImpl;
import com.jclark.xsl.sax. OutputMethodHandlerImpl;
import com.jclark.xsl.sax. Destination;
import com.jclark.xsl.sax. FileDescriptorDestination;
import com.jclark.xsl.sax. FileDestination;

import com.faa.sax.util.      DBParser;
import com.faa.sax.util.test. SAXPrintHandlers;

// Interfaces
import com.jclark.xsl.sax. XSLProcessor;

// Exceptions
import java.sql. SQLException;


  /** 
      A class to mediate the interaction of JRun and an XSLT 
      processor. Basically a faade for calling XT.
   */
public class XSLTCoordinator
{

// ******************************************         Constructors / Destructors

    /**
       Create an XSLTCoordinator based on the properties file given
       @param properties file name of the properties

    */
    public XSLTCoordinator(File newOut,String properties) 
    {
	out = newOut;

	try 
	    {
		myDB.load(new FileInputStream(properties));
		Class.forName(myDB.getProperty("driver"));
	    }
	catch (java.lang.Exception e) 
	    {
		System.out.println("wrong database params " + e);
	    }
    }

    /** 
	  A compensation for default values in java. (pass a fixed string to the
	  normal constructor  
   */
    public XSLTCoordinator(File newOut) 
    {
	new XSLTCoordinator(newOut,"bugtracker.properties");
    }


     /** 
	 Simply pass the appropriate parameters to the DBParser, and register
	 the printing handlers.
     */
    private void setUpParser()
    {
	try {
	    conn = DriverManager.
		getConnection(myDB.getProperty("URL"),
			      myDB.getProperty("user"),
			      myDB.getProperty("password"));
	    stmt = conn.createStatement();
	    rs = stmt.executeQuery("SELECT * FROM " +  
                                    myDB.getProperty("table"));
	 
	    Vector representAsAtts = new Vector();
	    representAsAtts.add(new Integer(5));
	    representAsAtts.add(new Integer(6));
	    myParser = new DBParser();
	    myParser.setParseParameters(rs,"bugList","bug",representAsAtts); 
	}
	catch (java.lang.Exception e) 
	    {
		System.err.println("Failed to connect with the database " + e);
	    }
    }
    


      /** 
	  Perform the actual transformation, using the given styleshet
	  @param stylesheet the filename of the stylesheet to use
      */
    public boolean transform(String stylesheet)
    {
	try {
	    XSLProcessorImpl xsl = new XSLProcessorImpl();

	    setUpParser();

	    String stylesheetParserClass = myDB.getProperty("parser");
	    if(stylesheetParserClass == null)
		stylesheetParserClass = DEFAULT_PARSER;
	    Object parserObj = 
                   Class.forName(stylesheetParserClass).newInstance();
	    // set the parsers for the source and the stylesheet
	    xsl.setParser(myParser,(Parser)parserObj);
	    xsl.setErrorHandler(new ErrorHandlerImpl());
	    OutputMethodHandlerImpl outputMethodHandler = 
		new OutputMethodHandlerImpl(xsl);
	    xsl.setOutputMethodHandler(outputMethodHandler);
	    File ss = new File(stylesheet);

	    Destination dest;
	    if(out == null) 
		dest = new FileDescriptorDestination(FileDescriptor.out);
	    else
		dest = new FileDestination(out);

	    
	    outputMethodHandler.setDestination(dest);	

	    
	    boolean suc = transform(xsl,fileInputSource(ss));
	    cleanUpParser();
	    return suc;
	    
	}
	catch (java.lang.Exception e) {
	    System.err.println("transform" + e.toString());
	}
	return false;
    }

      /** 
	  Simply close the connection to the database
   */
 
    public void cleanUpParser()
    {
	 // Clean up.
	 try {
	   if (rs != null) 
	     rs.close();
	   if (stmt != null) 
	     stmt.close();
	   if (conn != null) 
	     conn.close();
	 }
	 catch (SQLException sqlex) {
	   System.err.println("SQL exception in finally block");
	   sqlex.printStackTrace();
	 }
    }

    /**
       transform using the given processor
    */
    boolean transform(XSLProcessor xsl,
	              InputSource stylesheetSource) 
    {
	try {
	    xsl.loadStylesheet(stylesheetSource);
	    // Just a dummy, so XT doesn't complain, but the real data is coming
	    // from the database
	    xsl.parse(fileInputSource(new File("c:\\temp\\dummy.xml")));
	    return true;
	}
	catch (java.lang.Exception e) {
	    System.err.println("Transforming xsl: "  + e.toString());
	    e.printStackTrace(System.err);
	}
	return false;
    }

      /** 
	  create an input source out of a File
      @param File the file
      @return the correspondent InputSource
   */
 
    static public InputSource fileInputSource(File file) {
	String path = file.getAbsolutePath();
	String fSep = System.getProperty("file.separator");
	if (fSep != null && fSep.length() == 1)
	    path = path.replace(fSep.charAt(0), '/');
	if (path.length() > 0 && path.charAt(0) != '/')
	    path = '/' + path;
	try {
	    return new InputSource(new URL("file", "", path).toString());
	}
	catch (java.net.MalformedURLException e) {
	    /* According to the spec this could only happen if the file
	       protocol were not recognized. */
	    System.err.println("Malformed input url" + e);
	    throw new Error("unexpected MalformedURLException");
	}
    }


    Connection   conn     = null;
    Statement    stmt     = null;
    ResultSet    rs       = null;
    Properties   myDB     = new Properties();
    DBParser     myParser = null;
    File out      = null;
    static final String DEFAULT_PARSER = "com.jclark.xml.sax.Driver";


// ******************************************                 Private Classes
    static class ErrorHandlerImpl implements ErrorHandler {
	public void warning(SAXParseException e) {
	    System.err.println(e);
	}
	public void error(SAXParseException e) {
	    System.err.println(e);
	}
	public void fatalError(SAXParseException e) throws SAXException {
	    throw e;
	}
    }
}






